@@ -47,6 +47,16 @@ config_sample = {
                             "description": "Some post command",
                         },
                     ],
+                    # NOTE: the scenario here is that the tests must not be defined in v1,
+                    # but must be defined in default; then we check that container_opts
+                    # were properly inherited from v1 and not from default
+                    "tests": [
+                        {"commandline": ["echo", "1"]},
+                        {
+                            "container_opts": {"environment": {"LEVEL": "3"}},
+                            "commandline": ["echo", "1"],
+                        },
+                    ],
                 },
                 "v1": {
                     "container_opts": {
@@ -60,6 +70,7 @@ config_sample = {
                             "description": "Some pre command",
                         }
                     ],
+                    "validation_commands": [],  # no validation for v1
                 },
             },
             "github_repo_name": "my-gh-repo",
@@ -71,6 +82,7 @@ config_sample = {
     "spec_versions": ["v1", "v2"],
     "spec_sections": {},
     "user_agent_client_name": "MyClient",
+    "validation_commands": [{"commandline": ["echo", "1"]}],
 }
 
 
@@ -140,6 +152,23 @@ def check_config(c):
         "workdir": ".",
     }
 
+    # make sure that container_opts are inherited properly when commands are defined
+    # on "default" generation, but container_opts are overriden on a specific version
+    assert java.test_commands_for("v1")[0].container_opts == {
+        "environment": {"LEVEL": "2", "V1": "y"},
+        "image": "other:image",
+        "inherit": False,
+        "system": False,
+        "workdir": ".",
+    }
+    assert java.test_commands_for("v1")[1].container_opts == {
+        "environment": {"LEVEL": "3", "V1": "y"},
+        "image": "other:image",
+        "inherit": True,
+        "system": False,
+        "workdir": ".",
+    }
+
     # test templates config
     tplcfg = java.templates_config_for("v1")
     assert tplcfg.patches == ["patch1", "patch2"]
@@ -179,6 +208,18 @@ def check_config(c):
         java.chevron_vars_for("v1", "spec/v1/full_spec.yaml") == expected_chevron_vars
     )
 
+    assert java.validation_commands_for("v1") == []
+    v2vcs = java.validation_commands_for("v2")
+    assert len(v2vcs) == 1
+    assert v2vcs[0].container_opts == {
+        "environment": {"JAVA": "y", "DEFAULT": "y", "LEVEL": "2"},
+        "image": "java:image",
+        "inherit": True,
+        "system": False,
+        "workdir": ".",
+    }
+    assert v2vcs[0].commandline == ["echo", "1"]
+
 
 def test_config_from_dict():
     c = Config.from_dict(config_sample)
